@@ -13,7 +13,8 @@ FP::PureArray::t -- tests for FP::PureArray
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
