@@ -19,7 +19,8 @@ currently just provides $html5_void_elements and $html5_void_element_h
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
